@@ -1,7 +1,5 @@
 """
 
-ro.py > accountinformation.py
-
 This file houses functions and classes that pertain to Roblox authenticated user account information.
 
 """
@@ -18,11 +16,17 @@ class AccountInformationMetadata:
     """
     def __init__(self, metadata_raw):
         self.is_allowed_notifications_endpoint_disabled = metadata_raw["isAllowedNotificationsEndpointDisabled"]
+        """Unsure what this does."""
         self.is_account_settings_policy_enabled = metadata_raw["isAccountSettingsPolicyEnabled"]
+        """Whether the account settings policy is enabled (unsure exactly what this does)"""
         self.is_phone_number_enabled = metadata_raw["isPhoneNumberEnabled"]
+        """Whether the user's linked phone number is enabled."""
         self.max_user_description_length = metadata_raw["MaxUserDescriptionLength"]
+        """Maximum length of the user's description."""
         self.is_user_description_enabled = metadata_raw["isUserDescriptionEnabled"]
+        """Whether the user's description is enabled."""
         self.is_user_block_endpoints_updated = metadata_raw["isUserBlockEndpointsUpdated"]
+        """Whether the UserBlock endpoints are updated (unsure exactly what this does)"""
 
 
 class PromotionChannels:
@@ -31,60 +35,80 @@ class PromotionChannels:
     """
     def __init__(self, promotion_raw):
         self.promotion_channels_visibility_privacy = promotion_raw["promotionChannelsVisibilityPrivacy"]
+        """Visibility of promotion channels."""
         self.facebook = promotion_raw["facebook"]
+        """Link to the user's Facebook page."""
         self.twitter = promotion_raw["twitter"]
+        """Link to the user's Twitter page."""
         self.youtube = promotion_raw["youtube"]
+        """Link to the user's YouTube page."""
         self.twitch = promotion_raw["twitch"]
+        """Link to the user's Twitch page."""
 
 
 class AccountInformation:
     """
     Represents authenticated client account information (https://accountinformation.roblox.com/)
     This is only available for authenticated clients as it cannot be accessed otherwise.
+
+    Parameters
+    ----------
+    requests : ro_py.utilities.requests.Requests
+        Requests object to use for API requests.
     """
     def __init__(self, requests):
         self.requests = requests
         self.account_information_metadata = None
         self.promotion_channels = None
-        self.update()
 
-    def update(self):
+    async def update(self):
         """
         Updates the account information.
-        :return: Nothing
         """
-        account_information_req = self.requests.get("https://accountinformation.roblox.com/v1/metadata")
+        account_information_req = await self.requests.get(
+            url="https://accountinformation.roblox.com/v1/metadata"
+        )
         self.account_information_metadata = AccountInformationMetadata(account_information_req.json())
-        promotion_channels_req = self.requests.get("https://accountinformation.roblox.com/v1/promotion-channels")
+        promotion_channels_req = await self.requests.get(
+            url="https://accountinformation.roblox.com/v1/promotion-channels"
+        )
         self.promotion_channels = PromotionChannels(promotion_channels_req.json())
 
-    def get_gender(self):
+    async def get_gender(self):
         """
         Gets the user's gender.
-        :return: RobloxGender
+
+        Returns
+        -------
+        ro_py.gender.RobloxGender
         """
-        gender_req = self.requests.get(endpoint + "v1/gender")
+        gender_req = await self.requests.get(endpoint + "v1/gender")
         return RobloxGender(gender_req.json()["gender"])
 
-    def set_gender(self, gender):
+    async def set_gender(self, gender):
         """
         Sets the user's gender.
-        :param gender: RobloxGender
-        :return: Nothing
+
+        Parameters
+        ----------
+        gender : ro_py.gender.RobloxGender
         """
-        self.requests.post(
+        await self.requests.post(
             url=endpoint + "v1/gender",
             data={
                 "gender": str(gender.value)
             }
         )
 
-    def get_birthdate(self):
+    async def get_birthdate(self):
         """
-        Returns the user's birthdate.
-        :return: datetime
+        Grabs the user's birthdate.
+
+        Returns
+        -------
+        datetime.datetime
         """
-        birthdate_req = self.requests.get(endpoint + "v1/birthdate")
+        birthdate_req = await self.requests.get(endpoint + "v1/birthdate")
         birthdate_raw = birthdate_req.json()
         birthdate = datetime(
             year=birthdate_raw["birthYear"],
@@ -93,13 +117,15 @@ class AccountInformation:
         )
         return birthdate
 
-    def set_birthdate(self, birthdate):
+    async def set_birthdate(self, birthdate):
         """
         Sets the user's birthdate.
-        :param birthdate: A datetime object.
-        :return: Nothing
+
+        Parameters
+        ----------
+        birthdate : datetime.datetime
         """
-        self.requests.post(
+        await self.requests.post(
             url=endpoint + "v1/birthdate",
             data={
               "birthMonth": birthdate.month,
