@@ -1,8 +1,7 @@
 """
 
-ro.py > gender.py
-
 I hate how Roblox stores gender at all, it's really strange as it's not used for anything.
+There's literally no point in storing this information.
 
 """
 
